@@ -31,8 +31,9 @@ and coordinates the 'handlers'->'actions'->'formatters' execution workflow
 
 import argparse
 from actions import list_gists, show, get, post, delete, update, authorize
+from actions import fork
 from handlers import handle_list, handle_show, handle_update, handle_authorize
-from handlers import handle_get, handle_post, handle_delete
+from handlers import handle_get, handle_post, handle_delete, handle_fork
 from formatters import format_list, format_post, format_update
 from formatters import format_get, format_show, format_delete, format_authorize
 from version import VERSION
@@ -57,6 +58,7 @@ def run(*args, **kwargs):
     __add_delete_parser(subparsers)
     __add_authorize_parser(subparsers)
     __add_version_parser(subparsers)
+    __add_fork_parser(subparsers)
 
     # Parse the arguments
     args = parser.parse_args()
@@ -152,7 +154,7 @@ def __add_create_parser(subparsers):
     parser_post.add_argument("-s", "--secret",
             help="""Github password. Overrides the default 'token' property
             in configuration file""")
-    parser_post.add_argument("-f", "--filename",
+    parser_post.add_argument("-f", "--filenames", nargs='+',
             help="Specify gist file to upload.", required=True)
     parser_post.add_argument("-p", "--private",
             help="""Private gist. (public by default)""",
@@ -184,7 +186,7 @@ def __add_update_parser(subparsers):
             in configuration file""")
     group1 = parser_update.add_argument_group("File options",
             "Update Gist files")
-    group1.add_argument("-f", "--filename",
+    group1.add_argument("-f", "--filenames", nargs='+',
              help="Gist file to update.")
     group11 = group1.add_mutually_exclusive_group()
     group11.add_argument("-n", "--new", action="store_true",
@@ -193,7 +195,7 @@ def __add_update_parser(subparsers):
     group11.add_argument("-r", "--remove", action="store_true",
             help="Delete file for the gist. '-f' (--filename) argument needed",
             default=False)
-    group11.add_argument("-i", "--input_dir",
+    group1.add_argument("-i", "--input_dir",
             help="Input directory where the source file is")
     group2 = parser_update.add_argument_group('Metadata options',
             "Update Gist General Data")
@@ -252,3 +254,23 @@ def __add_version_parser(subparsers):
             help="Print the version of the release")
     parser_version.set_defaults(handle_args=lambda x: (None,),
             func=lambda x: None, formatter=lambda x: VERSION)
+
+
+def __add_fork_parser(subparsers):
+    """ Define the subparser to handle 'fork' functionallity.
+
+    :param subparsers: the subparser entity
+    """
+
+    parser_fork = subparsers.add_parser("fork",
+            help="Fork another users' gists")
+    parser_fork.add_argument("gist_id",
+            help="Identifier of the Gist to fork")
+    parser_fork.add_argument("-u", "--user",
+            help="""Github user. Overrides the default 'user' property
+            in configuration file""")
+    parser_fork.add_argument("-s", "--secret",
+            help="""Github password. Overrides the default 'token' property
+            in configuration file""")
+    parser_fork.set_defaults(handle_args=handle_fork, func=fork,
+            formatter=format_post)
