@@ -30,7 +30,6 @@ data for the functions in 'actions' module.
 """
 
 import sys
-import os
 import utils
 import literals
 
@@ -82,17 +81,11 @@ def handle_update(args):
         print literals.CREDENTIAL_NOT_FOUND
         sys.exit()
 
-    # Define the source file
-    if args.filename:
-        if args.input_dir:
-            source_file = os.path.join(args.input_dir, args.filename)
-        else:
-            source_file = os.path.join("./", args.filename)
-    else:
-        source_file = None
+    if not args.input_dir:
+        args.input_dir = "./"
 
-    return (args.gist_id,  args.description, args.filename,
-        source_file, args.new, args.remove,
+    return (args.gist_id,  args.description, args.filenames,
+        args.input_dir, args.new, args.remove,
         utils.GithubFacade(args.user, credential))
 
 
@@ -115,16 +108,10 @@ def handle_post(args):
     else:
         public = True
 
-    # Define the source file
-    if args.filename:
-        if args.input_dir:
-            source_file = os.path.join(args.input_dir, args.filename)
-        else:
-            source_file = os.path.join("./", args.filename)
-    else:
-        source_file = None
+    if not args.input_dir:
+        args.input_dit = "./"
 
-    return (public, args.filename, source_file, args.description,
+    return (public, args.filenames, args.input_dir, args.description,
         utils.GithubFacade(args.user, credential))
 
 
@@ -140,6 +127,7 @@ def handle_get(args):
 
 def handle_delete(args):
     """ Handle the arguments to call the 'delete' gists functionality. """
+
     # Get the 'secret' argument if exists, otherwise take it from configuration
     # file. If 'secret' can not be loaded, raise an exception
     if args.secret:
@@ -156,3 +144,19 @@ def handle_delete(args):
 def handle_authorize(args):
     """ Handle the arguments to call the 'authorize' gists functionality. """
     return (utils.GithubFacade(args.user, args.secret),)
+
+
+def handle_fork(args):
+    """ Handle the arguments to call the 'fork' gists functionality. """
+
+    # Get the 'secret' argument if exists, otherwise take it from configuration
+    # file. If 'secret' can not be loaded, raise an exception
+    if args.secret:
+        credential = args.secret
+    else:
+        credential = config.getConfigToken()
+    if not credential:
+        print literals.CREDENTIAL_NOT_FOUND
+        sys.exit()
+
+    return args.gist_id, utils.GithubFacade(args.user, credential)
